==> xnu-1504.15.3.tar.gz: xnu-xnu-1504.15.3/osfmk/machine/commpage.h <==
/*
 * Copyright (c) 2000-2007 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 * 
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 * 
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 * 
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 * 
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */

#ifndef _MACHINE_COMMPAGE_H
#define _MACHINE_COMMPAGE_H

#if defined (__ppc__)
#include "ppc/commpage/commpage.h"
#elif defined (__i386__) || defined (__x86_64__)
#include "i386/commpage/commpage.h"
#else
#error architecture not supported
#endif

#ifndef	__ASSEMBLER__

extern	void	commpage_populate( void ); 	/* called once during startup */

#endif	/* __ASSEMBLER__ */

#endif	/* _MACHINE_COMMPAGE_H */

==> xnu-10002.1.13.tar.gz: xnu-xnu-10002.1.13/osfmk/machine/commpage.h <==
/*
 * Copyright (c) 2000-2007 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */

#ifndef _MACHINE_COMMPAGE_H
#define _MACHINE_COMMPAGE_H

#if defined (__i386__) || defined (__x86_64__)
#include "i386/commpage/commpage.h"
#elif defined (__arm__) || defined (__arm64__)
#include "arm/commpage/commpage.h"
#else
#error architecture not supported
#endif

#ifndef __ASSEMBLER__
#include <sys/commpage.h>

extern  void    commpage_populate( void );      /* called once during startup */
extern  void    commpage_text_populate( void );
#endif  /* __ASSEMBLER__ */

#endif  /* _MACHINE_COMMPAGE_H */
